@@ -709,6 +709,40 @@ class AzureNodeDriver(NodeDriver):
 
         return True
 
+    def ex_get_ratecard(self, offer_durable_id, currency='USD',
+                        locale='en-US', region='US'):
+        """
+        Get rate card
+
+        :param offer_durable_id: ID of the offer applicable for this
+        user account. (e.g. "0026P")
+        See http://azure.microsoft.com/en-us/support/legal/offer-details/
+        :type offer_durable_id: str
+
+        :param currency: Desired currency for the response (default: "USD")
+        :type currency: ``str``
+
+        :param locale: Locale (default: "en-US")
+        :type locale: ``str``
+
+        :param region: Region (two-letter code) (default: "US")
+        :type regions: ``str``
+
+        :return: A dictionary of rates whose ID's correspond to nothing at all
+        :rtype: ``dict``
+        """
+
+        action = "/subscriptions/%s/providers/Microsoft.Commerce/" \
+                 "RateCard" % (self.subscription_id,)
+        params = {"api-version": "2016-08-31-preview",
+                  "$filter": "OfferDurableId eq 'MS-AZR-%s' and "
+                             "Currency eq '%s' and "
+                             "Locale eq '%s' and "
+                             "RegionInfo eq '%s'" %
+                             (offer_durable_id, currency, locale, region)}
+        r = self.connection.request(action, params=params)
+        return r.object
+
     def ex_list_publishers(self, location=None):
         """
         List node image publishers.
