@@ -189,7 +189,7 @@ class Route53DNSDriver(DNSDriver):
         self._post_changeset(zone, batch)
         id = ':'.join((self.RECORD_TYPE_MAP[type], name))
         return Record(id=id, name=name, type=type, data=data, zone=zone,
-                      driver=self, extra=extra)
+                      driver=self, ttl=extra.get('ttl', None), extra=extra)
 
     def update_record(self, record, name=None, type=None, data=None,
                       extra=None):
@@ -216,7 +216,7 @@ class Route53DNSDriver(DNSDriver):
 
         id = ':'.join((self.RECORD_TYPE_MAP[type], name))
         return Record(id=id, name=name, type=type, data=data, zone=record.zone,
-                      driver=self, extra=extra)
+                      driver=self, ttl=extra.get('ttl', None), extra=extra)
 
     def delete_record(self, record):
         try:
@@ -270,7 +270,8 @@ class Route53DNSDriver(DNSDriver):
         records = []
         for value in values:
             record = Record(id=id, name=name, type=type, data=value, zone=zone,
-                            driver=self, extra=extra)
+                            driver=self, ttl=extra.get('ttl', None),
+                            extra=extra)
             records.append(record)
 
         return records
@@ -480,7 +481,9 @@ class Route53DNSDriver(DNSDriver):
 
         type = self._string_to_record_type(findtext(element=elem, xpath='Type',
                                                     namespace=NAMESPACE))
-        ttl = int(findtext(element=elem, xpath='TTL', namespace=NAMESPACE))
+        ttl = findtext(element=elem, xpath='TTL', namespace=NAMESPACE)
+        if ttl is not None:
+            ttl = int(ttl)
 
         value_elem = elem.findall(
             fixxpath(xpath='ResourceRecords/ResourceRecord',
@@ -503,7 +506,7 @@ class Route53DNSDriver(DNSDriver):
 
         id = ':'.join((self.RECORD_TYPE_MAP[type], name))
         record = Record(id=id, name=name, type=type, data=data, zone=zone,
-                        driver=self, extra=extra)
+                        driver=self, ttl=extra.get('ttl', None), extra=extra)
         return record
 
     def _get_more(self, rtype, **kwargs):
